@@ -7,10 +7,9 @@ import os, zipfile, requests, io
 import tempfile, shutil
 import platform
 
-from . import utils, static
-from . import version as cli_version
+from . import utils, static, VERSION, CORE_COMMIT
 from .static.pretext import pretext as core
-from .project import Target,Project
+from .project import Target, Project
 
 
 log = logging.getLogger('ptxlogger')
@@ -30,7 +29,7 @@ CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
     log,
     help="Sets the severity of log messaging: DEBUG for all, INFO (default) for most, then WARNING, ERROR, and CRITICAL for decreasing verbosity."
 )
-@click.version_option(cli_version(),message=cli_version())
+@click.version_option(VERSION,message=VERSION)
 @click.option('-t', '--targets', is_flag=True, help='Display list of build/view "targets" available in the project manifest.')
 def main(ctx,targets):
     """
@@ -68,12 +67,12 @@ def main(ctx,targets):
         os.chdir(utils.project_path())
         if utils.requirements_version() is None:
             log.warning("Project's CLI version could not be detected from `requirements.txt`.")
-        elif utils.requirements_version() != cli_version():
-            log.warning(f"Using CLI version {cli_version()} but project's `requirements.txt`")
+        elif utils.requirements_version() != VERSION:
+            log.warning(f"Using CLI version {VERSION} but project's `requirements.txt`")
             log.warning(f"is configured to use {utils.requirements_version()}. Consider either installing")
-            log.warning(f"CLI version {utils.requirements_version()} or updating `requirements.txt` to {cli_version()}.")
+            log.warning(f"CLI version {utils.requirements_version()} or updating `requirements.txt` to {VERSION}.")
         else:
-            log.debug(f"CLI version {cli_version()} matches requirements.txt {utils.requirements_version()}.")
+            log.debug(f"CLI version {VERSION} matches requirements.txt {utils.requirements_version()}.")
     else:
         log.info("No existing PreTeXt project found.")
     if ctx.invoked_subcommand is None:
@@ -95,12 +94,9 @@ def support():
     log.info("Please share the following information when posting to the")
     log.info("pretext-support Google Group.")
     log.info("")
-    with open(static.path('VERSION'), 'r') as version_file:
-        version = version_file.read().strip()
-        log.info(f"PreTeXt-CLI version: {version}")
-        log.info(f"    PyPI link: https://pypi.org/project/pretextbook/{version}/")
-    with open(static.path('CORE_COMMIT'), 'r') as commit_file:
-        log.info(f"PreTeXt core resources commit: {commit_file.read().strip()}")
+    log.info(f"PreTeXt-CLI version: {VERSION}")
+    log.info(f"    PyPI link: https://pypi.org/project/pretextbook/{VERSION}/")
+    log.info(f"PreTeXt core resources commit: {CORE_COMMIT}")
     log.info(f"OS: {platform.platform()}")
     log.info(f"Python version: {platform.python_version()}")
     log.info(f"Current working directory: {os.getcwd()}")
@@ -160,7 +156,7 @@ def new(template,directory,url_template):
         shutil.copytree(tmpsubdirname,directory,dirs_exist_ok=True)
     # generate requirements.txt
     with open(os.path.join(directory_fullpath,"requirements.txt"),"w") as f:
-        f.write(f"pretextbook == {cli_version()}")
+        f.write(f"pretextbook == {VERSION}")
     log.info(f"Success! Open `{directory_fullpath}/source/main.ptx` to edit your document")
     log.info(f"Then try to `pretext build` and `pretext view` from within `{directory_fullpath}`.")
 
@@ -194,7 +190,7 @@ def init(force):
         requirements_path = os.path.abspath('requirments-'+timestamp+'.txt')
         log.warning(f"You already have a requirements.txt file; the one suggested by PreTeXt will be created as {requirements_path} for comparison.\n")
     with open(requirements_path,"w") as f:
-        f.write(f"pretextbook == {cli_version()}")
+        f.write(f"pretextbook == {VERSION}")
     # Create publication file if one doesn't exist: 
     template_pub_path = static.path('templates','publication.ptx')
     project_pub_path = os.path.abspath(os.path.join('publication','publication.ptx'))
@@ -304,6 +300,7 @@ def build(target, format, source, output, stringparam, xsl, publication, clean,
     else:
         log.warning("Assets like latex-images will not be regenerated for this build")
         log.warning("(previously generated assets will be used if they exist).")
+        log.warning("To generate these assets before building, run `pretext build -g`.")
     project.build(target_name,clean)
 
 # pretext generate
@@ -408,15 +405,8 @@ def view(target,access,port,directory,watch,build,generate):
 @main.command(short_help="Deploys Git-managed project to GitHub Pages.",
     context_settings=CONTEXT_SETTINGS)
 @click.argument('target', required=False)
-@click.option(
-    '-m',
-    '--commit-message',
-    default="Update to PreTeXt project source.",
-    show_default=True,
-    help="""
-    Customize message to leave on Git commit for source updates.
-    """)
-def deploy(target,commit_message):
+@click.option('-u', '--update_source', is_flag=True, required=False)
+def deploy(target,update_source):
     """
     Automatically deploys most recent build of [TARGET] to GitHub Pages,
     making it available to the general public.
@@ -426,7 +416,7 @@ def deploy(target,commit_message):
     """
     target_name = target
     project = Project()
-    project.deploy(target_name,commit_message)
+    project.deploy(target_name,update_source)
 
 # pretext publish
 @main.command(short_help="OBSOLETE: use deploy",
